/*************************************************** 
  This is a library for our I2C LED Backpacks

  Designed specifically to work with the Adafruit LED Matrix backpacks 
  ----> http://www.adafruit.com/products/
  ----> http://www.adafruit.com/products/

  These displays use I2C to communicate, 2 pins are required to 
  interface. There are multiple selectable I2C addresses. For backpacks
  with 2 Address Select pins: 0x70, 0x71, 0x72 or 0x73. For backpacks
  with 3 Address Select pins: 0x70 thru 0x77

  Adafruit invests time and resources providing this open source code, 
  please support Adafruit and open-source hardware by purchasing 
  products from Adafruit!

  Written by Limor Fried/Ladyada for Adafruit Industries.  
  BSD license, all text above must be included in any redistribution
 ****************************************************/

/*
This code is a modified version for Atmel Studio C Environment
and relates to seven segment display only.
Modified by Dirk Rodenhausen (dirk at avr-praxis.de)
*/

#ifndef __sevenseg_led_backpack_h__
#define __sevenseg_led_backpack_h__

#define HT16K33_CMD_BLINK 0x80
#define HT16K33_BLINK_DISPLAYON 0x01
#define HT16K33_BLINK_OFF 0
#define HT16K33_BLINK_2HZ  1
#define HT16K33_BLINK_1HZ  2
#define HT16K33_BLINK_HALFHZ  3

#define HT16K33_CMD_BRIGHTNESS 0xE0
#define HT16K33_CMD_OSCILLATOR 0x20

void LEDDriver_SetBrightness(uint8_t b);
void LEDDriver_BlinkRate(uint8_t b);
void LEDDriver_SetOscillator(bool osc_on);
void LEDDriver_Init(void);
void LEDDriver_WriteDisplay(void);
void LEDDriver_DisplayClear(void);
void LEDDriver_DisplayFill(void);
void LEDDriver_DrawColon(bool state);
void LEDDriver_WriteDigitNumber(uint8_t digit, uint8_t number, bool dot);
void LEDDriver_DrawDigitDot(uint8_t digit, bool dot);
void LEDDriver_WriteDigitRaw(uint8_t digit, uint8_t bitmask);
void LEDDriver_DisplayDecimal8(uint8_t d);
void LEDDriver_DisplayDecimal16(uint16_t d);
void LEDDriver_DisplayHex8(uint8_t d);
void LEDDriver_DisplayHex16(uint16_t d);

uint16_t displaybuffer[8]; 
uint8_t displaymodule_addr;


#endif