/**********************************************************************************
* C Library for the seven segment I2C LED backpack from Adafruit
*
* Written for Atmel Studio C
*  
* Recommended development environment:
*
* Atmel Studio 6
* ---> http://www.atmel.com/Microsite/atmel_studio6/default.aspx
* Developmentboard Nano from dev-tools.de.
* ---> http://www.dev-tools.de/index.php/development-boards/developmentboard-nano
*
* We invests time and resources providing this open source code,
* please support www.avr-praxis.de and open-source hardware
* by purchasing products from www.mikrocontroller-praxis.de!
*
* Written by Dirk Rodenhausen (dirk at avr-praxis.de)
*
* Our webpages:
* http://www.avr-praxis.de
* German discussion forum related to AVR microcontroller family.
*
* http://www.mikrocontroller-praxis.de
* Onlineshop where you can purchase ...
* Adafruit seven segment I2C LED backpack
* ---> http://mikrocontroller-praxis.de/index.php?page=search&keywords=i2c+backpack&x=0&y=0
* Dev-Tools Nano development board for AVR microcontrollers whith DIP
* ---> http://mikrocontroller-praxis.de/de/Development-Tools/AVR-DevTools-Development-Board/Developmentboard-NANO-fuer-AVR-DIP.html
*
* http://www.dev-tools.de
* Further resources of products available from www.mikrocontroller-praxis.de.
*
*
* BSD license, all text above must be included in any redistribution.
* Please read the License.txt file.
* AVR is a registered trademark of Atmel corporation.
**********************************************************************************/


#include <avr/io.h>
#include <util/delay.h> 
#include <stdlib.h>
#include <stdint.h>
#include <stdbool.h>

#include "SevenSegment_LEDBackpack.h"
#include "TWI_Master.h"

int main (void)
{

  I2C_Init();

  // 7bit address (A2..0 = 0b000 ... 0b111 -> Address 0x70 ..0x77)
  displaymodule_addr = 0x70; 

  LEDDriver_Init();

  while(1)
  {

    uint16_t blinkcounter = 0;
    bool drawColon = false;

    for (uint16_t counter = 0; counter < 10000; counter ++)
	{
	
	  LEDDriver_DisplayDecimal16(counter);         // Displays decimal 0..9999
	  // LEDDriver_DisplayDecimal8((uint8_t)counter); // Displays decimal 0..255
      // LEDDriver_DisplayHex8((uint8_t)counter);     // Displays hexadecimal 0x00..0xFF	  
      // LEDDriver_DisplayHex16(counter);             // Displays hexadecimal 0x0000..0xFFFF
	  
	  LEDDriver_DrawColon(drawColon);
      
	  LEDDriver_DrawDigitDot(0, drawColon);
	  LEDDriver_DrawDigitDot(1, drawColon);	  
	  LEDDriver_DrawDigitDot(3, drawColon);	  
	  LEDDriver_DrawDigitDot(4, drawColon);	  
	  
	    
      blinkcounter+=10;
      if (blinkcounter < 500) {
        drawColon = false;
      } else if (blinkcounter < 1000) {
        drawColon = true;
      } else {
        blinkcounter = 0;
      }
	
      LEDDriver_WriteDisplay();
      _delay_ms(10);
	  
    }

  }

  return 0;
}